@@ -1,18 +1,17 @@
 module Jekyll
   module Commands
     class Build < Command
-
       class << self
-
         # Create the Mercenary command for the Jekyll CLI for this Command
         def init_with_program(prog)
           prog.command(:build) do |c|
             c.syntax      'build [options]'
             c.description 'Build your site'
+            c.alias :b
 
             add_build_options(c)
 
-            c.action do |args, options|
+            c.action do |_, options|
               options["serving"] = false
               Jekyll::Commands::Build.process(options)
             end
@@ -22,7 +21,8 @@ module Jekyll
         # Build your jekyll site
         # Continuously watch if `watch` is set to true in the config.
         def process(options)
-          Jekyll.logger.log_level = :error if options['quiet']
+          # Adjust verbosity quickly
+          Jekyll.logger.adjust_verbosity(options)
 
           options = configuration_from_options(options)
           site = Jekyll::Site.new(options)
@@ -32,7 +32,14 @@ module Jekyll
           else
             build(site, options)
           end
-          watch(site, options) if options['watch']
+
+          if options.fetch('detach', false)
+            Jekyll.logger.info "Auto-regeneration:", "disabled when running server detached."
+          elsif options.fetch('watch', false)
+            watch(site, options)
+          else
+            Jekyll.logger.info "Auto-regeneration:", "disabled. Use --watch to enable."
+          end
         end
 
         # Build your Jekyll site.
@@ -42,13 +49,16 @@ module Jekyll
         #
         # Returns nothing.
         def build(site, options)
+          t = Time.now
           source      = options['source']
           destination = options['destination']
+          incremental = options['incremental']
           Jekyll.logger.info "Source:", source
           Jekyll.logger.info "Destination:", destination
+          Jekyll.logger.info "Incremental build:", (incremental ? "enabled" : "disabled. Enable with --incremental")
           Jekyll.logger.info "Generating..."
           process_site(site)
-          Jekyll.logger.info "", "done."
+          Jekyll.logger.info "", "done in #{(Time.now - t).round(3)} seconds."
         end
 
         # Private: Watch for file changes and rebuild the site.
@@ -57,13 +67,11 @@ module Jekyll
         # options - A Hash of options passed to the command
         #
         # Returns nothing.
-        def watch(site, options)
-          Deprecator.gracefully_require 'jekyll-watch'
-          Jekyll::Commands::Watch.watch(site, options)
+        def watch(_site, options)
+          External.require_with_graceful_fail 'jekyll-watch'
+          Jekyll::Watcher.watch(options)
         end
-
       end # end of class << self
-
     end
   end
 end
