@@ -2,7 +2,6 @@ module Jekyll
   module Commands
     class Clean < Command
       class << self
-
         def init_with_program(prog)
           prog.command(:clean) do |c|
             c.syntax 'clean [subcommand]'
@@ -10,8 +9,8 @@ module Jekyll
 
             add_build_options(c)
 
-            c.action do |args, _|
-              Jekyll::Commands::Clean.process({})
+            c.action do |_, options|
+              Jekyll::Commands::Clean.process(options)
             end
           end
         end
@@ -37,7 +36,6 @@ module Jekyll
             Jekyll.logger.info "Nothing to do for #{metadata_file}."
           end
         end
-
       end
     end
   end
