@@ -5,7 +5,7 @@ module Jekyll
 
       priority :lowest
 
-      def matches(ext)
+      def matches(_ext)
         true
       end
 
