@@ -15,7 +15,7 @@ module Jekyll
     def file(filename)
       filename = @site.in_source_dir(filename).sub(/\A#{Regexp.escape(@site.source)}\//, '')
 
-      LiquidRenderer::File.new(self, filename).tap do |file|
+      LiquidRenderer::File.new(self, filename).tap do
         @stats[filename] ||= {}
         @stats[filename][:count] ||= 0
         @stats[filename][:count] += 1
