@@ -4,7 +4,7 @@ module Jekyll
     def initialize(site, dir)
       @site = site
       @dir = dir
-      @unfiltered_content = Array.new
+      @unfiltered_content = []
     end
 
     # Read all the files in <source>/<dir>/ for Yaml header and create a new Page
@@ -14,7 +14,7 @@ module Jekyll
     #
     # Returns an array of static files.
     def read(files)
-      files.map{ |file| @unfiltered_content << StaticFile.new(@site, @site.source, @dir, file)}
+      files.map { |file| @unfiltered_content << StaticFile.new(@site, @site.source, @dir, file) }
       @unfiltered_content
     end
   end
