@@ -60,22 +60,19 @@ eos
         site = context.registers[:site]
 
         site.posts.docs.each do |p|
-          if @post == p
-            return p.url
-          end
+          return p.url if @post == p
         end
 
         # New matching method did not match, fall back to old method
         # with deprecation warning if this matches
 
         site.posts.docs.each do |p|
-          if @post.deprecated_equality p
-            Jekyll::Deprecator.deprecation_message "A call to '{{ post_url #{@post.name} }}' did not match " +
-              "a post using the new matching method of checking name " +
-              "(path-date-slug) equality. Please make sure that you " +
-              "change this tag to match the post's name exactly."
-            return p.url
-          end
+          next unless @post.deprecated_equality p
+          Jekyll::Deprecator.deprecation_message "A call to '{{ post_url #{@post.name} }}' did not match " \
+            "a post using the new matching method of checking name " \
+            "(path-date-slug) equality. Please make sure that you " \
+            "change this tag to match the post's name exactly."
+          return p.url
         end
 
         raise ArgumentError.new <<-eos
