@@ -1,6 +1,7 @@
 module Jekyll
   module Utils
-    module Platforms extend self
+    module Platforms
+      extend self
 
       # Provides jruby? and mri? which respectively detect these two types of
       # tested Engines we support, in the future we might probably support the
@@ -18,7 +19,6 @@ module Jekyll
 
       { :windows? => /mswin|mingw|cygwin/, :linux? => /linux/, \
           :osx? => /darwin|mac os/, :unix? => /solaris|bsd/ }.each do |k, v|
-
         define_method k do
           !!(
             RbConfig::CONFIG["host_os"] =~ v
