@@ -21,19 +21,19 @@ class TestCleaner < JekyllUnitTest
     end
 
     should "keep the parent directory" do
-      assert File.exist?(dest_dir('to_keep'))
+      assert_exist dest_dir('to_keep')
     end
 
     should "keep the child directory" do
-      assert File.exist?(dest_dir('to_keep/child_dir'))
+      assert_exist dest_dir('to_keep', 'child_dir')
     end
 
     should "keep the file in the directory in keep_files" do
-      assert File.exist?(File.join(dest_dir('to_keep/child_dir'), 'index.html'))
+      assert_exist dest_dir('to_keep', 'child_dir', 'index.html')
     end
 
     should "delete the file in the directory not in keep_files" do
-      assert !File.exist?(File.join(dest_dir('to_keep'), 'index.html'))
+      refute_exist dest_dir('to_keep', 'index.html')
     end
   end
 
@@ -41,8 +41,8 @@ class TestCleaner < JekyllUnitTest
     setup do
       clear_dest
 
-      FileUtils.mkdir_p(source_dir('no_files_inside/child_dir'))
-      FileUtils.touch(File.join(source_dir('no_files_inside/child_dir'), 'index.html'))
+      FileUtils.mkdir_p(source_dir('no_files_inside', 'child_dir'))
+      FileUtils.touch(source_dir('no_files_inside', 'child_dir', 'index.html'))
 
       @site = fixture_site
       @site.process
@@ -57,15 +57,15 @@ class TestCleaner < JekyllUnitTest
     end
 
     should "keep the parent directory" do
-      assert File.exist?(dest_dir('no_files_inside'))
+      assert_exist dest_dir('no_files_inside')
     end
 
     should "keep the child directory" do
-      assert File.exist?(dest_dir('no_files_inside/child_dir'))
+      assert_exist dest_dir('no_files_inside', 'child_dir')
     end
 
     should "keep the file" do
-      assert File.exist?(File.join(dest_dir('no_files_inside/child_dir'), 'index.html'))
+      assert_exist source_dir('no_files_inside', 'child_dir', 'index.html')
     end
   end
 end
