@@ -49,5 +49,19 @@ class TestConvertible < JekyllUnitTest
       assert_match(/invalid byte sequence in UTF-8/, out)
       assert_match(/#{File.join(@base, name)}/, out)
     end
+
+    should "parse the front-matter but show an error if permalink is empty" do
+      name = 'empty_permalink.erb'
+      assert_raises(Errors::InvalidPermalinkError) do
+        @convertible.read_yaml(@base, name)
+      end
+    end
+
+    should "parse the front-matter correctly whitout permalink" do
+      out = capture_stderr do
+        @convertible.read_yaml(@base, 'front_matter.erb')
+      end
+      refute_match(/Invalid permalink/, out)
+    end
   end
 end
