@@ -4,15 +4,14 @@ class TestGeneratedSite < JekyllUnitTest
   context "generated sites" do
     setup do
       clear_dest
-      config = Jekyll::Configuration::DEFAULTS.merge({'source' => source_dir, 'destination' => dest_dir})
 
-      @site = fixture_site config
+      @site = fixture_site
       @site.process
       @index = File.read(dest_dir('index.html'))
     end
 
     should "ensure post count is as expected" do
-      assert_equal 48, @site.posts.size
+      assert_equal 49, @site.posts.size
     end
 
     should "insert site.posts into the index" do
@@ -31,16 +30,22 @@ class TestGeneratedSite < JekyllUnitTest
     end
 
     should "hide unpublished page" do
-      assert !File.exist?(dest_dir('/unpublished.html'))
+      refute_exist dest_dir('/unpublished.html')
     end
 
     should "not copy _posts directory" do
-      assert !File.exist?(dest_dir('_posts'))
+      refute_exist dest_dir('_posts')
+    end
+
+    should "process a page with a folder permalink properly" do
+      about = @site.pages.find {|page| page.name == 'about.html' }
+      assert_equal dest_dir('about', 'index.html'), about.destination(dest_dir)
+      assert_exist dest_dir('about', 'index.html')
     end
 
     should "process other static files and generate correct permalinks" do
-      assert File.exist?(dest_dir('/about/index.html'))
-      assert File.exist?(dest_dir('/contacts.html'))
+      assert_exist dest_dir('contacts.html')
+      assert_exist dest_dir('dynamic_file.php')
     end
 
     should "print a nice list of static files" do
@@ -58,8 +63,7 @@ OUTPUT
   context "generating limited posts" do
     setup do
       clear_dest
-      config = Jekyll::Configuration::DEFAULTS.merge({'source' => source_dir, 'destination' => dest_dir, 'limit_posts' => 5})
-      @site = fixture_site config
+      @site = fixture_site("limit_posts" => 5)
       @site.process
       @index = File.read(dest_dir('index.html'))
     end
@@ -71,17 +75,13 @@ OUTPUT
     should "ensure limit posts is 0 or more" do
       assert_raises ArgumentError do
         clear_dest
-        config = Jekyll::Configuration::DEFAULTS.merge({'source' => source_dir, 'destination' => dest_dir, 'limit_posts' => -1})
-
-        @site = fixture_site config
+        @site = fixture_site("limit_posts" => -1)
       end
     end
 
     should "acceptable limit post is 0" do
       clear_dest
-      config = Jekyll::Configuration::DEFAULTS.merge({'source' => source_dir, 'destination' => dest_dir, 'limit_posts' => 0})
-
-      assert Site.new(config), "Couldn't create a site with the given limit_posts."
+      assert fixture_site("limit_posts" => 0), "Couldn't create a site with limit_posts=0."
     end
   end
 end
