@@ -4,7 +4,7 @@ class TestLayoutReader < JekyllUnitTest
   context "reading layouts" do
     setup do
       config = Jekyll::Configuration::DEFAULTS.merge({'source' => source_dir, 'destination' => dest_dir})
-      @site = fixture_site config
+      @site = fixture_site(config)
     end
 
     should "read layouts" do
