@@ -3,42 +3,42 @@ require 'helper'
 class TestSite < JekyllUnitTest
   context "configuring sites" do
     should "have an array for plugins by default" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS)
+      site = Site.new default_configuration
       assert_equal [File.join(Dir.pwd, '_plugins')], site.plugins
     end
 
     should "look for plugins under the site directory by default" do
       site = Site.new(site_configuration)
-      assert_equal [File.join(source_dir, '_plugins')], site.plugins
+      assert_equal [source_dir('_plugins')], site.plugins
     end
 
     should "have an array for plugins if passed as a string" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS.merge({'plugins_dir' => '/tmp/plugins'}))
+      site = Site.new(site_configuration({ 'plugins_dir' => '/tmp/plugins' }))
       assert_equal ['/tmp/plugins'], site.plugins
     end
 
     should "have an array for plugins if passed as an array" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS.merge({'plugins_dir' => ['/tmp/plugins', '/tmp/otherplugins']}))
+      site = Site.new(site_configuration({ 'plugins_dir' => ['/tmp/plugins', '/tmp/otherplugins'] }))
       assert_equal ['/tmp/plugins', '/tmp/otherplugins'], site.plugins
     end
 
     should "have an empty array for plugins if nothing is passed" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS.merge({'plugins_dir' => []}))
+      site = Site.new(site_configuration({ 'plugins_dir' => [] }))
       assert_equal [], site.plugins
     end
 
-    should "have an empty array for plugins if nil is passed" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS.merge({'plugins_dir' => nil}))
-      assert_equal [], site.plugins
+    should "have the default for plugins if nil is passed" do
+      site = Site.new(site_configuration({ 'plugins_dir' => nil }))
+      assert_equal [source_dir('_plugins')], site.plugins
     end
 
     should "expose default baseurl" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS)
+      site = Site.new(default_configuration)
       assert_equal Jekyll::Configuration::DEFAULTS['baseurl'], site.baseurl
     end
 
     should "expose baseurl passed in from config" do
-      site = Site.new(Jekyll::Configuration::DEFAULTS.merge({'baseurl' => '/blog'}))
+      site = Site.new(site_configuration({ 'baseurl' => '/blog' }))
       assert_equal '/blog', site.baseurl
     end
   end
@@ -174,9 +174,11 @@ class TestSite < JekyllUnitTest
         coffeescript.coffee
         contacts.html
         deal.with.dots.html
+        dynamic_file.php
         environment.html
         exploit.md
         foo.md
+        humans.txt
         index.html
         index.html
         main.scss
@@ -274,25 +276,25 @@ class TestSite < JekyllUnitTest
 
       should 'remove orphaned files in destination' do
         @site.process
-        assert !File.exist?(dest_dir('obsolete.html'))
-        assert !File.exist?(dest_dir('qux'))
-        assert !File.exist?(dest_dir('quux'))
-        assert File.exist?(dest_dir('.git'))
-        assert File.exist?(dest_dir('.git/HEAD'))
+        refute_exist dest_dir('obsolete.html')
+        refute_exist dest_dir('qux')
+        refute_exist dest_dir('quux')
+        assert_exist dest_dir('.git')
+        assert_exist dest_dir('.git', 'HEAD')
       end
 
       should 'remove orphaned files in destination - keep_files .svn' do
         config = site_configuration('keep_files' => %w{.svn})
         @site = Site.new(config)
         @site.process
-        assert !File.exist?(dest_dir('.htpasswd'))
-        assert !File.exist?(dest_dir('obsolete.html'))
-        assert !File.exist?(dest_dir('qux'))
-        assert !File.exist?(dest_dir('quux'))
-        assert !File.exist?(dest_dir('.git'))
-        assert !File.exist?(dest_dir('.git/HEAD'))
-        assert File.exist?(dest_dir('.svn'))
-        assert File.exist?(dest_dir('.svn/HEAD'))
+        refute_exist dest_dir('.htpasswd')
+        refute_exist dest_dir('obsolete.html')
+        refute_exist dest_dir('qux')
+        refute_exist dest_dir('quux')
+        refute_exist dest_dir('.git')
+        refute_exist dest_dir('.git', 'HEAD')
+        assert_exist dest_dir('.svn')
+        assert_exist dest_dir('.svn', 'HEAD')
       end
     end
 
@@ -464,6 +466,14 @@ class TestSite < JekyllUnitTest
         @site = Site.new(site_configuration('profile' => true))
       end
 
+      # Suppress output while testing
+      setup do
+        $stdout = StringIO.new
+      end
+      teardown do
+        $stdout = STDOUT
+      end
+
       should "print profile table" do
         expect(@site.liquid_renderer).to receive(:stats_table)
         @site.process
